yakumo.keystone

Package yakumo :: Package keystone |
[hide private]
[frames] | no frames]

# Package keystone

source code

Submodules | [hide private]
yakumo.keystone.v2: Sub client class for Identity V2 API yakumo.keystone.v2.endpoint: Resource class and its manager for endpoints in Identity V2 API yakumo.keystone.v2.project: Resource class and its manager for projects in Identity V2 API yakumo.keystone.v2.role: Resource class and its manager for roles in Identity V2 API yakumo.keystone.v2.service: Resource class and its manager for services in Identity V2 API yakumo.keystone.v2.user: Resource class and its manager for users in Identity V2 API yakumo.keystone.v3: Sub client class for Identity V3 API yakumo.keystone.v3.credential: Resource class and its manager for credentials in Identity V3 API yakumo.keystone.v3.domain: Resource class and its manager for domains in Identity V3 API yakumo.keystone.v3.endpoint: Resource class and its manager for endpoints in Identity V3 API yakumo.keystone.v3.group: Resource class and its manager for groups in Identity V3 API yakumo.keystone.v3.project: Resource class and its manager for projects in Identity V3 API yakumo.keystone.v3.region: Resource class and its manager for regions in Identity V3 API yakumo.keystone.v3.role: Resource class and its manager for roles in Identity V3 API yakumo.keystone.v3.service: Resource class and its manager for services in Identity V3 API yakumo.keystone.v3.user: Resource class and its manager for users in Identity V3 API

Variables | [hide private]
| __package__ = `None`